#[repr(u8)]pub enum Rxignore {
READ = 0,
IGNORE = 1,
}Variants
READ = 0
Read received data. Received data must be read in order to allow transmission to progress. SPI transmit will halt when the receive data FIFO is full. In slave mode, an overrun error will occur if received data is not read before new data is received.
IGNORE = 1
Ignore received data. Received data is ignored, allowing transmission without reading unneeded received data. No receiver flags are generated.
Implementations